//	PhilChooserStatusbar.h - TextEditor and buttons for the PhilChooser
//							 Component.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#ifndef PHILCHOOSERSTATUSBAR_H_
#define PHILCHOOSERSTATUSBAR_H_

class Phil;

///	TextEditor and buttons for the PhilChooser Component.
/*!
	This contains the usual widgets you get in a file chooser - a TextEditor
	with the currently-selected file's name, a ComboBox with a selection
	of file extension wildcards, and ok and cancel buttons.

	When the ok or cancel button is pressed, a change message is broadcast,
	so PhilChooser can be informed (if getFile() returns an empty String,
	the user clicked cancel, else they clicked ok).
 */
class PhilChooserStatusbar : public Component,
							 public ChangeListener,
							 public ComboBoxListener,
							 public ButtonListener,
							 public ChangeBroadcaster,
							 public TextEditorListener
{
  public:
	///	Constructor.
	/*!
		\param parentComponent Pointer to the owning Phil.
	 */
	PhilChooserStatusbar(Phil *parentComponent);
	///	Destructor.
	~PhilChooserStatusbar();

	///	Used to place the widgets correctly.
	void resized();
	///	Called when the parent PhilComponent's state has changed.
	void changeListenerCallback(void *objectThatHasChanged);
	///	Called when the user selects a different wildcard.
	void comboBoxChanged(ComboBox *box);
	///	Called when the user clicks ok or cancel.
	void buttonClicked(Button *button);

	///	Overridden to do nothing.
	void textEditorTextChanged(TextEditor &editor) {};
	///	So the dialog will exit when the user hits return.
	void textEditorReturnKeyPressed(TextEditor &editor);
	///	Overridden to do nothing.
	void textEditorEscapeKeyPressed(TextEditor &editor) {};
	///	Overridden to do nothing.
	void textEditorFocusLost(TextEditor &editor) {};

	///	Called to get the file the user selected
	/*!
		(just the file name, not the path).
	 */
	const String& getFile() const {return selectedFile;};

	juce_UseDebuggingNewOperator
  private:
	///	Label for fileName.
	Label *fileNameLabel;
	///	Holds the name of the currently-selected file/directory.
	TextEditor *fileName;
	///	Label for wildcards.
	Label *wildcardLabel;
	///	Holds all the wildcards used to mask out files types.
	ComboBox *wildcards;
	///	Ok button.
	TextButton *ok;
	///	Cancel button.
	TextButton *cancel;

	///	Pointer to the owning Phil.
	Phil *parent;

	///	The currently-selected file/directory.
	String selectedFile;
};

#endif
