//	SliderControl.h - Combination of widgets to send OSC messages based around
//					  a slider.
//	----------------------------------------------------------------------------
//	This file is part of Mouse To OSC, a simple OSC-outputting program.
//	Copyright (c) 2006 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#ifndef SLIDERCONTROL_H_
#define SLIDERCONTROL_H_

//------------------------------------------------------------------------------
///	Combination of widgets to send OSC messages based around a slider.
class SliderControl : public Component,
					  public ChangeBroadcaster,
					  public SliderListener
{
  public:
	///	Constructor.
	SliderControl();
	///	Destructor.
	~SliderControl();

	///	Used to place the various widgets.
	void resized();

	///	Called when the user drags the XYPad control.
	void sliderValueChanged(Slider *slider);

	///	Returns the OSC address for the slider.
	String getAddress() const {return addressEditor->getText();};
	///	Returns the max value.
	String getMax() const {return sliderMax->getText();};
	///	Returns the min value.
	String getMin() const {return sliderMin->getText();};
	///	Returns the current value for the slider.
	float getSliderVal() const;
	///	Returns the MIDI CC.
	String getCc() const {return ccEditor->getText();};

	///	Set the OSC address.
	void setAddress(const String& val);
	///	Set the max value.
	void setMax(const String& val);
	///	Set the min value.
	void setMin(const String& val);
	///	Set the slider's value.
	void setValue(float val);
	///	Set the MIDI CC.
	void setCc(const String& val);

	///	Sets the slider's value, normalised to 0->1.
	/*!
		Also sends a change message when called.
	 */
	void setValueNorm(float val);

    juce_UseDebuggingNewOperator
  private:
	///	Label for the address editor.
	Label *addressLabel;
	///	Address text editor.
	TextEditor *addressEditor;
	///	Slider control.
	Slider *sliderControl;

	///	Slider min text editor.
	TextEditor *sliderMin;
	///	Slider max text editor.
	TextEditor *sliderMax;
	///	MIDI CC text editor.
	TextEditor *ccEditor;
};

//------------------------------------------------------------------------------
///	Structure containing the values for the various SliderControl widgets.
typedef struct
{
	String address;
	String max;
	String min;
	float val;
	String cc;
} SliderControlValues;

#endif
